@@ -465,4 +465,9 @@ circ_mask <- function(d, n, offset = 1) {
   dist <- sqrt((g$Var1 - n / 2 - offset) ^ 2 + (g$Var2 - n / 2 - offset) ^ 2)
   dist <- matrix(dist, n, n)
   return(dist <= d / 2)
-}
\ No newline at end of file
+}
+
+#' Check if an object is defined, which is the same as being not NULL.
+#' @param x object to test for being NULL.
+#' @return logical value.
+is.def <- function(x) !is.null(x)
